mod case;
mod contains;
mod distance;
mod ends_with;
mod expand;
mod index_of;
mod join;
mod length;
mod replace;
mod reverse;
mod starts_with;
mod stats;
mod substring;
mod trim;

pub use case::*;
pub use contains::SubCommand as StrContains;
pub use distance::SubCommand as StrDistance;
pub use ends_with::SubCommand as StrEndswith;
pub use expand::SubCommand as StrExpand;
pub use index_of::SubCommand as StrIndexOf;
pub use join::*;
pub use length::SubCommand as StrLength;
pub use replace::SubCommand as StrReplace;
pub use reverse::SubCommand as StrReverse;
pub use starts_with::SubCommand as StrStartsWith;
pub use stats::SubCommand as StrStats;
pub use substring::SubCommand as StrSubstring;
pub use trim::Trim as StrTrim;
